@@ -8,7 +8,7 @@ my $tx = Text::Xslate->new(
     path  => ["$Bin/template"],
 );
 
-print $tx->render({data => [
+print $tx->render('list.tx', {data => [
     { title => 'Islands in the stream' },
     { title => 'Programming Perl'      },
     { title => 'River out of Eden'     },
