@@ -4,7 +4,7 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.001_04';
+our $VERSION = '0.001_05';
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -248,7 +248,7 @@ Text::Xslate - High performance template engine (ALPHA)
 
 =head1 VERSION
 
-This document describes Text::Xslate version 0.001_04.
+This document describes Text::Xslate version 0.001_05.
 
 =head1 SYNOPSIS
 
@@ -383,6 +383,13 @@ Operator precedence:
 
     (TODO)
 
+=head2 Template inclusion
+
+    ? include "foo.tx"
+
+Xslate templates may be recursively included, but including depth is
+limited to 100.
+
 =head2 Template inheritance
 
 (NOT YET IMPLEMENTED)
